=======
History
=======

1.0.0 (2020-09-03)
------------------

* First release on PyPI.

1.0.1 (2020-09-07)
------------------

* Automation create (CRUD) API
* Update template API
* Update zemfrog release information.

1.0.2 (2020-09-08)
------------------

* Update API structure

1.0.3 (2020-09-08)
------------------

* re-upload

1.0.4 (2020-09-09)
------------------

* fix manifest file

1.0.5 (2020-09-10)
------------------

* add command boilerplate
* add schema command

1.0.6 (2020-09-15)
------------------

* add jwt authentication
* refactor blueprint boilerplate
* add send async email
* fix celery

1.0.7 (2020-09-19)
------------------

* Fix: `#8 <https://github.com/zemfrog/zemfrog/issues/8>`_
* flask-apispec integration.
* improve authentication.
* add default schema models.
* Fix: rest api boilerplate
* IMPROVE: Added a prompt if a schema model exists.
* IMPROVE: add zemfrgo to requirements
* DOC: add README to project boilerplate
